part of firebase_model_notifier;

extension UserExtensions on User {
  bool get isEmpty {
    return uid.isEmpty;
  }

  bool get isNotEmpty {
    return uid.isNotEmpty;
  }
}

extension NullableUserExtensions on User? {
  bool get isEmpty {
    if (this == null) {
      return true;
    }
    return this!.uid.isEmpty;
  }

  bool get isNotEmpty {
    if (this == null) {
      return false;
    }
    return this!.uid.isNotEmpty;
  }
}

extension GeoMapExtensions<K, V> on Map<K, V> {
  /// Get the geo point corresponding to [key] in the map.
  ///
  /// If [key] is not found, the geo point of [orElse] is returned.
  GeoPoint getAsGeoPoint(K key, [GeoPoint? orElse]) {
    assert(key != null, "The key is empty.");
    if (!containsKey(key)) {
      return orElse ?? const GeoPoint(0, 0);
    }
    return (this[key] as GeoPoint?) ?? orElse ?? const GeoPoint(0, 0);
  }

  /// Get the geo data corresponding to [key] in the map.
  ///
  /// If [key] is not found, the geo data of [orElse] is returned.
  GeoData getAsGeoData(K key, [GeoData? orElse]) {
    assert(key != null, "The key is empty.");
    if (!containsKey(key)) {
      return orElse ?? const GeoData();
    }
    return (this[key] as GeoData?) ?? orElse ?? const GeoData();
  }
}

extension NullableGeoMapExtensions<K, V> on Map<K, V>? {
  /// Get the geo point corresponding to [key] in the map.
  ///
  /// If [key] is not found, the geo point of [orElse] is returned.
  GeoPoint getAsGeoPoint(K key, [GeoPoint? orElse]) {
    assert(key != null, "The key is empty.");
    if (this == null || !containsKey(key)) {
      return orElse ?? const GeoPoint(0, 0);
    }
    return (this![key] as GeoPoint?) ?? orElse ?? const GeoPoint(0, 0);
  }

  /// Get the geo data corresponding to [key] in the map.
  ///
  /// If [key] is not found, the geo data of [orElse] is returned.
  GeoData getAsGeoData(K key, [GeoData? orElse]) {
    assert(key != null, "The key is empty.");
    if (this == null || !containsKey(key)) {
      return orElse ?? const GeoData();
    }
    return (this![key] as GeoData?) ?? orElse ?? const GeoData();
  }
}
